Imports System.IO
Imports System.IO.Compression

Public Class Form1

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        Dim file_name As String = Application.StartupPath
        If file_name.EndsWith("\bin\Debug") Then
            file_name = file_name.Substring(0, file_name.LastIndexOf("\bin\Debug"))
        End If
        txtOriginalFile.Text = file_name & "\Form1.vb"
        txtCompressedFile.Text = file_name & "\Form1.vb.gz"
        txtDecompressedFile.Text = file_name & "\Form1.vb.ungz"
    End Sub

    Private Sub btnGo_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnGo.Click
        ' Compress.
        GZipFile(txtOriginalFile.Text, txtCompressedFile.Text)

        ' Decompress.
        GUnzipFile(txtCompressedFile.Text, txtDecompressedFile.Text)

        ' Compare with the original.
        CompareFiles(txtOriginalFile.Text, txtDecompressedFile.Text)
    End Sub

    ' Compress a file.
    Private Sub GZipFile(ByVal from_file As String, ByVal to_file As String)
        Dim num_bytes As Long
        Dim buf() As Byte

        ' Read the input file into a buffer.
        Using from_stream As New FileStream(from_file, FileMode.Open, FileAccess.Read, FileShare.Read)
            num_bytes = from_stream.Length
            ReDim buf(num_bytes - 1)
            from_stream.Read(buf, 0, num_bytes)
            from_stream.Close()
        End Using ' from_stream

        ' Write the buffer to the output file.
        Using to_stream As New FileStream(to_file, FileMode.Create, FileAccess.Write, FileShare.Write)
            Using zip_stream As New GZipStream(to_stream, CompressionMode.Compress)
                zip_stream.Write(buf, 0, num_bytes)
                zip_stream.Close()
            End Using ' zip_stream
            to_stream.Close()
        End Using ' to_stream
    End Sub

    ' Decompress a file.
    Private Sub GUnzipFile(ByVal from_file As String, ByVal to_file As String)
        Dim buf() As Byte

        ' Read the input file into a buffer.
        Using from_stream As New FileStream(from_file, FileMode.Open, FileAccess.Read, FileShare.Read)
            Using zip_stream As New GZipStream(from_stream, CompressionMode.Decompress)
                Const CHUNK As Integer = 1024
                Dim total_bytes_read As Integer = 0
                Do
                    ' Enlarge the buffer.
                    ReDim Preserve buf(total_bytes_read + CHUNK - 1)

                    ' Read the next chunk.
                    Dim bytes_read As Integer = zip_stream.Read(buf, total_bytes_read, CHUNK)
                    total_bytes_read += bytes_read

                    ' See if we're done.
                    If bytes_read < CHUNK Then
                        ' We're done. Make the buffer fit the data.
                        ReDim Preserve buf(total_bytes_read - 1)
                        Exit Do
                    End If
                Loop

                zip_stream.Close()
            End Using ' zip_stream
            from_stream.Close()
        End Using ' from_stream

        ' Write the buffer into the output file.
        Using to_stream As New FileStream(to_file, FileMode.Create, FileAccess.Write, FileShare.Write)
            to_stream.Write(buf, 0, buf.Length)
            to_stream.Close()
        End Using ' to_stream
    End Sub

    ' Compare two files.
    Private Sub CompareFiles(ByVal filename1 As String, ByVal filename2 As String)
        Dim file1() As Byte = My.Computer.FileSystem.ReadAllBytes(filename1)
        Dim file2() As Byte = My.Computer.FileSystem.ReadAllBytes(filename2)

        Dim files_different As Boolean = False
        If file1.Length <> file2.Length Then
            files_different = True
        Else
            For i As Integer = 0 To file1.Length - 1
                If file1(i) <> file2(i) Then
                    files_different = True
                    Exit For
                End If
            Next i
        End If

        If files_different Then
            MessageBox.Show("The files are different", "Error", MessageBoxButtons.OK, MessageBoxIcon.Information)
        Else
            MessageBox.Show("The files are identical", "Success", MessageBoxButtons.OK, MessageBoxIcon.Information)
        End If
    End Sub
End Class
